==> airdcpp-webui-1.0.2.tgz: package/src/components/table/VirtualTable.jsx <==
import React from 'react';

import TableActions from 'actions/TableActions';

import TableFooter from './TableFooter';
import TableContainer from './TableContainer';
import RowDataLoader from './RowDataLoader';

import './style.css';
import 'fixed-data-table/dist/fixed-data-table.css';


const VirtualTable = React.createClass({
	propTypes: {
		/**
		 * Elements to append to the table footer
		 */
		footerData: React.PropTypes.node,

		/**
		 * Returns a node to render if there are no rows to display
		 */
		emptyRowsNodeGetter: React.PropTypes.func,

		/**
		 * Possible ID of the current view (items will be cleared when the ID changes)
		 */
		viewId: React.PropTypes.any,

		/**
		 * Store containing sessions (must be provided together with entityId)
		 */
		sessionStore: React.PropTypes.object,

		/**
		 * Custom filter that will be displayed in addition to regular text filter
		 */
		customFilter: React.PropTypes.node,
	},

	componentWillMount() {
		this._dataLoader = new RowDataLoader(this.props.store, () => this.forceUpdate() );

		this.start(this.props.entityId);
	},

	componentDidMount() {
		this.unsubscribe = this.props.store.listen(this._dataLoader.onItemsUpdated.bind(this._dataLoader));
	},

	componentWillUnmount() {
		this.close();
		this.unsubscribe();
	},

	componentWillReceiveProps(nextProps) {
		if (nextProps.entityId !== this.props.entityId) {
			this.close();

			this.start(nextProps.entityId);
		}

		if (nextProps.viewId != this.props.viewId) {
			if (this.props.store.paused) {
				// We need to receive the new items
				TableActions.pause(this.props.store.viewUrl, false);
			}

			TableActions.clear(this.props.store.viewUrl);
		}
	},

	moduleExists() {
		if (!this.props.entityId) {
			return true;
		}

		return this.props.sessionStore.getSession(this.props.entityId);
	},

	start(entityId) {
		const { store } = this.props;

		TableActions.init(store.viewUrl, entityId);
		TableActions.setSort(store.viewUrl, store.sortProperty, store.sortAscending);
	},

	close() {
		// Don't send the close command if the session was removed
		TableActions.close(this.props.store.viewUrl, this.moduleExists());
	},

	render: function () {
		const { footerData, emptyRowsNodeGetter, ...other } = this.props;

		if (this.props.emptyRowsNodeGetter && this.props.store.totalCount === -1) {
			// Row count is unknown, don't flash the table
			return <div className="virtual-table"/>;
		}

		if (this.props.emptyRowsNodeGetter && this.props.store.totalCount === 0) {
			return this.props.emptyRowsNodeGetter();
		}

		//console.log('Render virtual table');
		return (
			<div className="virtual-table">
				<TableContainer 
					{ ...other }
					dataLoader={this._dataLoader}
				/>

				<TableFooter
					store={ this.props.store }
					customFilter={ this.props.customFilter }
					footerData={ footerData }
				/>
			</div>
		);
	}
});

export default VirtualTable;

==> airdcpp-webui-1.0.8.tgz: package/src/components/table/VirtualTable.jsx <==
import React from 'react';

import TableActions from 'actions/TableActions';

import TableFooter from './TableFooter';
import TableContainer from './TableContainer';
import RowDataLoader from './RowDataLoader';

import './style.css';
import 'fixed-data-table/dist/fixed-data-table.css';


const VirtualTable = React.createClass({
	propTypes: {
		/**
		 * Elements to append to the table footer
		 */
		footerData: React.PropTypes.node,

		/**
		 * Returns a node to render if there are no rows to display
		 */
		emptyRowsNodeGetter: React.PropTypes.func,

		/**
		 * Possible ID of the current view (items will be cleared when the ID changes)
		 */
		viewId: React.PropTypes.any,

		/**
		 * Store containing sessions (must be provided together with entityId)
		 */
		sessionStore: React.PropTypes.object,

		/**
		 * Custom filter that will be displayed in addition to regular text filter
		 */
		customFilter: React.PropTypes.node,
	},

	componentWillMount() {
		this._dataLoader = new RowDataLoader(this.props.store, () => this.forceUpdate() );

		this.start(this.props.entityId);
	},

	componentDidMount() {
		this.unsubscribe = this.props.store.listen(this._dataLoader.onItemsUpdated.bind(this._dataLoader));
	},

	componentWillUnmount() {
		this.close();
		this.unsubscribe();
	},

	componentWillReceiveProps(nextProps) {
		if (nextProps.entityId !== this.props.entityId) {
			this.close();

			this.start(nextProps.entityId);
		}

		if (nextProps.viewId != this.props.viewId) {
			if (this.props.store.paused) {
				// We need to receive the new items
				TableActions.pause(this.props.store.viewUrl, false);
			}

			TableActions.clear(this.props.store.viewUrl);
		}
	},

	moduleExists() {
		if (!this.props.entityId) {
			return true;
		}

		return this.props.sessionStore.getSession(this.props.entityId);
	},

	start(entityId) {
		const { store } = this.props;

		TableActions.init(store.viewUrl, entityId);
		TableActions.setSort(store.viewUrl, store.sortProperty, store.sortAscending);
	},

	close() {
		// Don't send the close command if the session was removed
		TableActions.close(this.props.store.viewUrl, this.moduleExists());
	},

	render: function () {
		const { footerData, emptyRowsNodeGetter, ...other } = this.props;

		if (emptyRowsNodeGetter && this.props.store.totalCount === -1) {
			// Row count is unknown, don't flash the table
			return <div className="virtual-table"/>;
		}

		if (emptyRowsNodeGetter && this.props.store.totalCount === 0) {
			return emptyRowsNodeGetter();
		}

		//console.log('Render virtual table');
		return (
			<div className="virtual-table">
				<TableContainer 
					{ ...other }
					dataLoader={this._dataLoader}
				/>

				<TableFooter
					store={ this.props.store }
					customFilter={ this.props.customFilter }
					footerData={ footerData }
				/>
			</div>
		);
	}
});

export default VirtualTable;
